@@ -730,8 +730,8 @@ from sqlalchemy import sql
                 con=con_str, 
                 index_col=pk_column, 
                 meta=df_meta, 
-                # bytes_per_chunk="100 MB"
-                npartitions=1,  # temporary force partition to 1 because of max connection of source limit
+                bytes_per_chunk="300 MB"
+                # npartitions=1,  # temporary force partition to 1 because of max connection of source limit
             )
         
         return ddf
